CREATE TABLE `$TableName$`
(
    `id`                        bigint   NOT NULL COMMENT '主键',
    `device_id`                 int      NOT NULL COMMENT '设备标识',
    `created_time`              datetime NOT NULL COMMENT '数据落库时间',
    `collection_time`           datetime NOT NULL COMMENT '采集指令下发时间',
    `receive_time`              datetime NOT NULL COMMENT '接收到数据时间',
    `cas_pressure`              decimal(10, 2) NULL DEFAULT NULL COMMENT '套压；MPa；-3表示现场仪表通信故障',
    `oil_pressure`              decimal(10, 2) NULL DEFAULT NULL COMMENT '油压；MPa；-3表示现场仪表通信故障',
    `alarm`                     int NULL DEFAULT NULL COMMENT '报警信息；1高压集气压力低2低压集气压力高3是柱塞危险上升4 柱塞快速上升次数超过设定值',
    `solenoid_valve_status`     int NULL DEFAULT NULL COMMENT '电磁阀状态；0-未知；1-关状态；2-开状态；',
    `open_well_remaining_time`  varchar(10) NULL DEFAULT NULL COMMENT '定时开井剩余时间；分钟',
    `close_well_remaining_time` varchar(10) NULL DEFAULT NULL COMMENT '定时关井剩余时间；分钟',
    `plug_arrival_status`       int NULL DEFAULT NULL COMMENT '柱塞到达信号；0-未到达；1-到达；',
    `plug_too_fast_count`       int NULL DEFAULT NULL COMMENT '柱塞过快次数；次',
    `plug_rising_speed`         int NULL DEFAULT NULL COMMENT '柱塞上升速度；米/分钟',
    `downstream_pressure`       decimal(10, 2) NULL DEFAULT NULL COMMENT '阀后压力；MPa；-3表示现场仪表通信故障',
    `solenoid_valve_opening`    decimal(10, 1) NULL DEFAULT NULL COMMENT '电控阀阀门开度；%；保留1位小数；开度范围0~100%',
    `reserve`                   varchar(10) NULL DEFAULT NULL COMMENT '预留',
    `pre_pressure`              decimal(10, 2) NULL DEFAULT NULL COMMENT '柱塞外输压力；MPa；-3表示现场仪表通信故障',
    `run_mode`                  int NULL DEFAULT NULL COMMENT '运行制度；0-未知；1-定时开关井；2-压力优化微升；3-自动优化；',
    `well_status`               int NULL DEFAULT NULL COMMENT '开关井控制；0-初始值；1-开井；2-关井；',
    `gas_collection_method`     int NULL DEFAULT NULL COMMENT '集气方式；1-高压集气；2-低压集气；',
    `high_pressure_protection`  decimal(10, 2) NULL DEFAULT NULL COMMENT '高压保护压力；MPa；低压集气方式  高压保护设置；',
    `low_pressure_protection`   decimal(10, 2) NULL DEFAULT NULL COMMENT '低压保护压力；MPa；高压集气方式  低压保护设置；',
    `too_fast_count`            int NULL DEFAULT NULL COMMENT '过快次数设置；次',
    `dangerous_rise_time`       varchar(10) NULL DEFAULT NULL COMMENT '危险上升时间；秒，HH:mm:ss',
    `too_fast_rise_time`        varchar(10) NULL DEFAULT NULL COMMENT '过快上升时间；秒，HH:mm:ss',
    `open_well_time`            decimal(10, 2) NULL DEFAULT NULL COMMENT '开井时间设置；小时',
    `close_well_time`           decimal(10, 2) NULL DEFAULT NULL COMMENT '关井时间设置；小时',
    `open_well_cas_pressure`    decimal(10, 2) NULL DEFAULT NULL COMMENT '套压开井压力；MPa；压力优化微升模式；',
    `little_rise_cas_pressure`  decimal(10, 2) NULL DEFAULT NULL COMMENT '套压微升压力；MPa；压力优化微升模式；',
    `check_stability_time`      varchar(10) NULL DEFAULT NULL COMMENT '检测稳定时间；秒，HH:mm:ss',
    `min_close_well_time`       varchar(10) NULL DEFAULT NULL COMMENT '最小关井时间；分钟，HH:mm',
    `max_close_well_time`       varchar(10) NULL DEFAULT NULL COMMENT '最大关井时间；分钟，HH:mm',
    `min_open_well_time`        varchar(10) NULL DEFAULT NULL COMMENT '最小开井时间；分钟，HH:mm',
    `max_open_well_time`        varchar(10) NULL DEFAULT NULL COMMENT '最大开井时间；分钟，HH:mm',
    `well_depth`                int NULL DEFAULT NULL COMMENT '气井深度；米',
    `produce_mode`              int NULL DEFAULT NULL COMMENT '生产制度；1-常开；2-常关；3-柱塞气举',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `udx_device_create_time` (`device_id` ASC, `collection_time` ASC) USING BTREE COMMENT '设备采集数据唯一键'
) ENGINE = InnoDB COMMENT = '维尔普斯设备ID：$DeviceId$的采集数据'